@@ -12,6 +12,7 @@ Author: Heikki Toivonen
 import base64
 import logging
 import os
+import platform
 import time
 import warnings
 
@@ -243,6 +244,7 @@ class X509TestCase(unittest.TestCase):
         req.set_version(0)
         self.assertEqual(req.get_version(), 0)
 
+    @unittest.skipIf(platform.system() == 'Windows', 'Skip on Windows.')
     def test_mkcert(self):
         for utc in (True, False):
             req, pk = self.mkreq(1024)
@@ -257,15 +259,20 @@ class X509TestCase(unittest.TestCase):
             cert.set_version(2)
             cert.set_subject(sub)
             t = int(time.time()) + time.timezone
+            log.debug('t = %s',
+                time.strftime("%a, %d %b %Y %H:%M:%S %z", time.localtime(t)))
             if utc:
                 now = ASN1.ASN1_UTCTIME()
             else:
                 now = ASN1.ASN1_TIME()
             now.set_time(t)
+            log.debug('now = %s', now)
             now_plus_year = ASN1.ASN1_TIME()
             now_plus_year.set_time(t + 60 * 60 * 24 * 365)
+            log.debug('now_plus_year = %s', now_plus_year)
             cert.set_not_before(now)
             cert.set_not_after(now_plus_year)
+            log.debug('cert = %s', cert.get_not_before())
             self.assertEqual(str(cert.get_not_before()), str(now))
             self.assertEqual(str(cert.get_not_after()), str(now_plus_year))
 
@@ -581,10 +588,27 @@ class X509TestCase(unittest.TestCase):
         self.assertEqual(cert.get_serial_number(),
                          127614157056681299805556476275995414779)
 
+    @unittest.skipIf(platform.system() == 'Windows', 'Skip on Windows.')
     def test_date_after_2050_working(self):
         cert = X509.load_cert('tests/bad_date_cert.crt')
         self.assertEqual(str(cert.get_not_after()), 'Feb  9 14:57:46 2116 GMT')
 
+    @unittest.skipIf(platform.system() == 'Windows', 'Skip on Windows.')
+    def test_date_reference_counting(self):
+        """x509_get_not_before() and x509_get_not_after() return internal
+        pointers into X509. As the returned ASN1_TIME objects do not store any
+        reference to the X509 itself, they become invalid when the last
+        reference to X509 goes out of scope and the underlying memory is freed.
+
+        https://gitlab.com/m2crypto/m2crypto/-/issues/325
+        """
+        cert = X509.load_cert('tests/bad_date_cert.crt')
+        not_before = cert.get_not_before()
+        not_after = cert.get_not_after()
+        del cert
+        self.assertEqual(str(not_before), 'Mar  4 14:57:46 2016 GMT')
+        self.assertEqual(str(not_after), 'Feb  9 14:57:46 2116 GMT')
+
     def test_easy_rsa_generated(self):
         """ Test loading a cert generated by easy RSA.
 
